@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2013 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -52,7 +52,7 @@ static gboolean stream_eos (GMimeStream *stream);
 static int stream_reset (GMimeStream *stream);
 static gint64 stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence);
 static gint64 stream_tell (GMimeStream *stream);
-static ssize_t stream_length (GMimeStream *stream);
+static gint64 stream_length (GMimeStream *stream);
 static GMimeStream *stream_substream (GMimeStream *stream, gint64 start, gint64 end);
 
 
@@ -139,7 +139,7 @@ stream_read (GMimeStream *stream, char *buf, size_t len)
 	
 	bound_end = stream->bound_end != -1 ? stream->bound_end : (gint64) mem->buffer->len;
 	
-	n = MIN (bound_end - stream->position, (gint64) len);
+	n = (size_t) MIN (bound_end - stream->position, (gint64) len);
 	if (n > 0) {
 		memcpy (buf, mem->buffer->data + stream->position, n);
 		stream->position += n;
@@ -165,13 +165,13 @@ stream_write (GMimeStream *stream, const char *buf, size_t len)
 	
 	if (stream->bound_end == -1) {
 		if (stream->position + len > mem->buffer->len)
-			g_byte_array_set_size (mem->buffer, stream->position + len);
+			g_byte_array_set_size (mem->buffer, (guint) stream->position + len);
 		
 		bound_end = mem->buffer->len;
 	} else
 		bound_end = stream->bound_end;
 	
-	n = MIN (bound_end - stream->position, (gint64) len);
+	n = (size_t) MIN (bound_end - stream->position, (gint64) len);
 	if (n > 0) {
 		memcpy (mem->buffer->data + stream->position, buf, n);
 		stream->position += n;
@@ -277,7 +277,7 @@ stream_seek (GMimeStream *stream, gint64 offset, GMimeSeekWhence whence)
 			return -1;
 		}
 		
-		g_byte_array_set_size (mem->buffer, real);
+		g_byte_array_set_size (mem->buffer, (guint) real);
 	}
 	
 	stream->position = real;
@@ -298,7 +298,7 @@ stream_tell (GMimeStream *stream)
 	return stream->position;
 }
 
-static ssize_t
+static gint64
 stream_length (GMimeStream *stream)
 {
 	GMimeStreamMem *mem = GMIME_STREAM_MEM (stream);
@@ -373,7 +373,7 @@ g_mime_stream_mem_new_with_byte_array (GByteArray *array)
 
 /**
  * g_mime_stream_mem_new_with_buffer:
- * @buffer: stream data
+ * @buffer: (array length=len) (element-type guint8): stream data
  * @len: buffer length
  *
  * Creates a new #GMimeStreamMem object and initializes the stream
@@ -403,7 +403,7 @@ g_mime_stream_mem_new_with_buffer (const char *buffer, size_t len)
  *
  * Gets the byte array from the memory stream.
  *
- * Returns: the byte array from the memory stream.
+ * Returns: (transfer none): the byte array from the memory stream.
  **/
 GByteArray *
 g_mime_stream_mem_get_byte_array (GMimeStreamMem *mem)
